@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: void
 version: 0.7.1
-id: void-0.7.1-662e5f28c19568c0aec0b2de7532ac34
-key: void_LcG25UDeDFWHJydhaH3NLH
+id: void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
+key: void_1xbLa44IAZR17AnlCjcnzk
 license: BSD3
 copyright: Copyright (C) 2008-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,13 +21,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/void-0.7.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/void-0.7.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/void-0.7.1
-hs-libraries: HSvoid-0.7.1-LcG25UDeDFWHJydhaH3NLH
+hs-libraries: HSvoid-0.7.1-1xbLa44IAZR17AnlCjcnzk
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
 haddock-interfaces: /usr/share/doc/haskell-void/html/void.haddock
 haddock-html: /usr/share/doc/haskell-void/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
